@@ -1,11 +1,6 @@
 #!/usr/bin/env python
 # GPL. (C) 2007 Paolo Patruno.
 
-from __future__ import division
-from __future__ import absolute_import
-from builtins import str
-from past.utils import old_div
-from builtins import object
 import logging
 import dbus
 from . import autoaudacious
@@ -147,7 +142,7 @@ def ManageAudacious (session,schedule):
 
 def secondi(delta):
     secondi=float(delta.seconds)
-    secondi=secondi+(old_div(delta.microseconds,100000.))
+    secondi=secondi+(delta.microseconds/100000.)
 
     if delta.days < 0 :
         secondi = secondi + (3600*24*delta.days)
